@@ -22,7 +22,7 @@ ROLE_EXCEPTION = HTTPException(
     headers={"WWW-Authenticate": "Bearer"},
 )
 oauth2_scheme = OAuth2PasswordBearer(
-    tokenUrl=f"{BASE_URL}/ppdb/v2/auth/all/login"
+    tokenUrl=f"{BASE_URL}ppdb/v2/auth/all/login"
 )
 
 class ObjectIdStr(str):
